# Speedcord
A simple discord API wrapper - without the bullshit

We have a discord! Join us at https://discord.gg/yxrprWz

## Contributions
Some ideas of what we need in speedcord
 
- Ability to only spawn select shards 
- Automatically scale shards when we gain guilds
- Make some simple typing functions
